
From: Yoichi Yuasa <yuasa@hh.iij4u.or.jp>

This patch has added pcibios_bus_to_resource to MIPS.

Signed-off-by: Yoichi Yuasa <yuasa@hh.iij4u.or.jp>
Cc: Ralf Baechle <ralf@linux-mips.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/mips/pci/pci.c    |   17 +++++++++++++++++
 include/asm-mips/pci.h |    2 ++
 2 files changed, 19 insertions(+)

diff -puN arch/mips/pci/pci.c~mips-add-pcibios_bus_to_resource arch/mips/pci/pci.c
--- devel/arch/mips/pci/pci.c~mips-add-pcibios_bus_to_resource	2005-08-21 22:20:33.000000000 -0700
+++ devel-akpm/arch/mips/pci/pci.c	2005-08-21 22:20:33.000000000 -0700
@@ -292,8 +292,25 @@ pcibios_resource_to_bus(struct pci_dev *
 	region->end = res->end - offset;
 }
 
+void __devinit
+pcibios_bus_to_resource(struct pci_dev *dev, struct resource *res,
+			struct pci_bus_region *region)
+{
+	struct pci_controller *hose = (struct pci_controller *)dev->sysdata;
+	unsigned long offset = 0;
+
+	if (res->flags & IORESOURCE_IO)
+		offset = hose->io_offset;
+	else if (res->flags & IORESOURCE_MEM)
+		offset = hose->mem_offset;
+
+	res->start = region->start + offset;
+	res->end = region->end + offset;
+}
+
 #ifdef CONFIG_HOTPLUG
 EXPORT_SYMBOL(pcibios_resource_to_bus);
+EXPORT_SYMBOL(pcibios_bus_to_resource);
 EXPORT_SYMBOL(PCIBIOS_MIN_IO);
 EXPORT_SYMBOL(PCIBIOS_MIN_MEM);
 #endif
diff -puN include/asm-mips/pci.h~mips-add-pcibios_bus_to_resource include/asm-mips/pci.h
--- devel/include/asm-mips/pci.h~mips-add-pcibios_bus_to_resource	2005-08-21 22:20:33.000000000 -0700
+++ devel-akpm/include/asm-mips/pci.h	2005-08-21 22:20:33.000000000 -0700
@@ -142,6 +142,8 @@ static inline void pci_dma_burst_advice(
 
 extern void pcibios_resource_to_bus(struct pci_dev *dev,
 	struct pci_bus_region *region, struct resource *res);
+extern void pcibios_bus_to_resource(struct pci_dev *dev,
+	struct resource *res, struct pci_bus_region *region);
 
 #ifdef CONFIG_PCI_DOMAINS
 
_
